Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: third_party/gsutil/boto/boto/ec2/elb/healthcheck.py

Issue 10199002: Upgrade gsutil to 3.4 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Addressed comments Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/gsutil/boto/boto/ec2/elb/healthcheck.py
diff --git a/third_party/gsutil/20110627/boto/boto/ec2/elb/healthcheck.py b/third_party/gsutil/boto/boto/ec2/elb/healthcheck.py
similarity index 70%
rename from third_party/gsutil/20110627/boto/boto/ec2/elb/healthcheck.py
rename to third_party/gsutil/boto/boto/ec2/elb/healthcheck.py
index 5b47d62addfb149494127fa8e2255227009cde56..6661ea15a2523b5a446f2c325cdc5856aea7eb43 100644
--- a/third_party/gsutil/20110627/boto/boto/ec2/elb/healthcheck.py
+++ b/third_party/gsutil/boto/boto/ec2/elb/healthcheck.py
@@ -21,11 +21,22 @@
class HealthCheck(object):
"""
- Represents an EC2 Access Point Health Check
+ Represents an EC2 Access Point Health Check. See
+ :ref:`elb-configuring-a-health-check` for a walkthrough on configuring
+ load balancer health checks.
"""
-
def __init__(self, access_point=None, interval=30, target=None,
healthy_threshold=3, timeout=5, unhealthy_threshold=5):
+ """
+ :ivar str access_point: The name of the load balancer this
+ health check is associated with.
+ :ivar int interval: Specifies how many seconds there are between
+ health checks.
+ :ivar str target: Determines what to check on an instance. See the
+ Amazon HealthCheck_ documentation for possible Target values.
+
+ .. _HealthCheck: http://docs.amazonwebservices.com/ElasticLoadBalancing/latest/APIReference/API_HealthCheck.html
+ """
self.access_point = access_point
self.interval = interval
self.target = target
@@ -54,6 +65,15 @@ class HealthCheck(object):
setattr(self, name, value)
def update(self):
+ """
+ In the case where you have accessed an existing health check on a
+ load balancer, this method applies this instance's health check
+ values to the load balancer it is attached to.
+
+ .. note:: This method will not do anything if the :py:attr:`access_point`
+ attribute isn't set, as is the case with a newly instantiated
+ HealthCheck instance.
+ """
if not self.access_point:
return
« no previous file with comments | « third_party/gsutil/boto/boto/ec2/elb/__init__.py ('k') | third_party/gsutil/boto/boto/ec2/elb/instancestate.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698